/**
 * Common types for DSP and PC programs.
 */

#include <stdint.h>

#pragma once

#define CONFIGURATION_ADDRESS_ON_DSP (0x80000000)

#define CORES_PER_DSP           (8)
#define MAX_DECODERS_PER_DSP    (64)
#define MAX_ENCODERS_PER_DSP    (64)

// Encoders
#define H264HP_ENCODER (0)

// Decoders
#define H264HP_DECODER (0)

#define DEFAULT_CONFIG_VALUE (-0xFFFF)

// Markers
#define CONFIGURATION_MARKER (0xABBA)

typedef struct {
    // General H.264 encoder settings
    int32_t entropyCodingMode;
    int32_t gopStructure;
    int32_t IDRFrameInterval;
    int32_t transformBlockSize;
    int32_t log2MaxFNumMinus4;
    int32_t picOrderCountType;
    int32_t interlaceCodingType;
    int32_t intraFrameInterval;
    int32_t mvAccuracy;
    int32_t bitRate;

    // General video encoder settings
    int32_t encodingPreset;
    int32_t maxInterFrameInterval;
    int32_t profile;
    int32_t level;

    // Rate control
    int32_t rateControlPreset;
    int32_t rcAlgo;
    int32_t qpI;
    int32_t qpP;
    int32_t qpOffsetB;
    int32_t qpMaxI;
    int32_t qpMinI;
    int32_t qpMaxP;
    int32_t qpMinP;
    int32_t qpMaxB;
    int32_t qpMinB;
    int32_t CbQPIndexOffset;
    int32_t CrQPIndexOffset;
    int32_t initialBufferLevel;
    int32_t HRDBufferSize;
    int32_t enablePRC;
    int32_t frameSkipAfterSceneChange;
    int32_t scalingMatrixPreset;

    // Inter coding
    int32_t interCodingPreset;
    int32_t MvRangeVerP;
    int32_t MvRangeHorP;
    int32_t MvRangeVerB;
    int32_t MvRangeHorB;
    int32_t maxMVperMB;

    // Intra coding
    int32_t intraCodingPreset;
    int32_t enableIntraPartition;
    int32_t intraRefreshMethod;
    int32_t intraRefreshRate;
    int32_t constrainedIntraPredEnable;

    // Slice coding
    int32_t sliceCodingPreset;
    int32_t streamFormat;
    int32_t sliceMode;
    int32_t sliceUnitSize;

    // Loop filter
    int32_t loopfilterPreset;
    int32_t loopfilterDisableIDC;
    int32_t filterOffsetA;
    int32_t filterOffsetB;

    // VUI coding
    int32_t vuiCodingPreset;
    int32_t aspectRatioInfoPresentFlag;
    int32_t aspectRatioIdc;
    int32_t videoSignalTypePresentFlag;
    int32_t videoFormat;
    int32_t videoFullRangeFlag;
    int32_t colourDescriptionPresentFlag;
    int32_t colourPrimaries;
    int32_t transferCharacteristics;
    int32_t matrixCoefficients;
    int32_t timingInfoPresentFlag;
} H264HPEncoderConfiguration;

typedef struct {
    int32_t coreIds[CORES_PER_DSP];
    int32_t decoderType;
    int32_t inputWidth;
    int32_t inputHeight;
    int32_t inputFrameRate;
    uint32_t inputBufferAddress;
} DspDecoderConfiguration;

typedef struct {
    int32_t coreIds[CORES_PER_DSP];
    int32_t inputDecoderIndex;
    int32_t encoderType;
    int32_t outputWidth;
    int32_t outputHeight;
    int32_t outputFrameRate;
    uint32_t outputBufferAddress;

    union {
        H264HPEncoderConfiguration h264HP;
    } configuration;
} DspEncoderConfiguration;

typedef struct {
    uint32_t marker;
    uint32_t reportingBufferAddresses[CORES_PER_DSP];
    int32_t reportingBufferSizes[CORES_PER_DSP];

    int32_t decodersCount;
    int32_t encodersCount;

    DspDecoderConfiguration decoderConfigurations[MAX_DECODERS_PER_DSP];
    DspEncoderConfiguration encoderConfigurations[MAX_ENCODERS_PER_DSP];
} DspConfiguration;
