#include <xdc/std.h>
#include <ti/ipc/GateMP.h>
#include <ti/sysbios/knl/Task.h>
#include "Common.h"

#define MULTICORE_API_GATE_NAME "multicoreGate"
#define BARRIER_GATE_NAME "barrierGate"
#define SHARED_DECODER_DATA_GATE_NAME "shDecGate"

extern cregister volatile unsigned int DNUM;

static GateMP_Handle multicoreApiGate = NULL;
static GateMP_Handle barrierGate = NULL;
static GateMP_Handle sharedDecoderDataGate = NULL;

static GateMP_Handle initGate(char* name, GateMP_LocalProtect localProtect) {
    GateMP_Handle gate = NULL;

    if (DNUM == 0) {
        GateMP_Params gateParams;
        GateMP_Params_init(&gateParams);
        gateParams.name = name;
        gateParams.localProtect = localProtect;
        gate = GateMP_create(&gateParams);
    } else {
        while (1) {
            int result = GateMP_open(name, &gate);

            if (result == GateMP_E_NOTFOUND) {
                Task_sleep(10);
            } else if (result == GateMP_S_SUCCESS) {
                break;
            } else {
                return NULL;
            }
        }
    }

    return gate;
}

ResultCode GlobalGates_init()
{
    multicoreApiGate = initGate(MULTICORE_API_GATE_NAME, GateMP_LocalProtect_THREAD);

    if (multicoreApiGate == NULL) {
        return ResultCode_Error;
    }

    barrierGate = initGate(BARRIER_GATE_NAME, GateMP_LocalProtect_TASKLET);

    if (barrierGate == NULL) {
        return ResultCode_Error;
    }

    sharedDecoderDataGate = initGate(SHARED_DECODER_DATA_GATE_NAME, GateMP_LocalProtect_TASKLET);

    if (sharedDecoderDataGate == NULL) {
        return ResultCode_Error;
    }

    return ResultCode_Ok;
}

GateMP_Handle GlobalGates_getMulticoreApiGate()
{
    return multicoreApiGate;
}

GateMP_Handle GlobalGates_getBarrierGate()
{
    return barrierGate;
}

GateMP_Handle GlobalGates_getSharedDecoderDataGate()
{
    return sharedDecoderDataGate;
}
